@@ -46,7 +46,7 @@
 #include"control.h"
 #include"datos.h"
 #include"dimentions.h"
-
+#include<rizoma_errors.h>
 #include"config_file.h"
 
 GtkWidget *user_entry;
@@ -98,10 +98,10 @@ int main (int argc, char *argv[])
 {
   GtkWidget *hbox;
   GtkWidget *vbox;
-  
+  GtkWidget *image;
   GtkWidget *label;
   GtkWidget *button;
-  
+  PangoAttrList *attrs;
   char *config_file;
 
   main_window = NULL;
@@ -114,7 +114,7 @@ int main (int argc, char *argv[])
   if (rizoma_config == NULL)
     {
       perror (g_strdup_printf ("Opening %s", config_file));
-      printf ("Para configurar su sistema debe ejecutar rizoma-config usando gksu(o similar) con la opcion -k");
+      printf ("Para configurar su sistema debe ejecutar rizoma-config usando gksu(o similar) con la opcion -k\n");
       exit (-1);
     }
 
@@ -127,47 +127,70 @@ int main (int argc, char *argv[])
     solo_venta = TRUE;
   else
     solo_venta = FALSE;
-
+  
   passwd_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (passwd_window), "Rizoma: Autenticación de Usuario");
   gtk_window_set_position (GTK_WINDOW (passwd_window), GTK_WIN_POS_CENTER_ALWAYS);
-  gtk_container_set_border_width (GTK_CONTAINER (passwd_window), 20);
+  //  gtk_container_set_border_width (GTK_CONTAINER (passwd_window), 10);
 
   gtk_widget_show (passwd_window);
   
   g_signal_connect (G_OBJECT (passwd_window), "destroy",
 		    G_CALLBACK (gtk_main_quit), NULL);
 
-  vbox = gtk_vbox_new (FALSE, 3);
-  gtk_widget_show (vbox);
+  vbox = gtk_vbox_new (TRUE, 3);
   gtk_container_add (GTK_CONTAINER (passwd_window), vbox);
-  
-  label = gtk_label_new ("");
+  gtk_widget_show (vbox);
+
+  hbox = gtk_hbox_new (FALSE, 3);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 3);
+  gtk_widget_show (hbox);
+
+  /*  attrs = pango_attr_list_new ();
+  pango_attr_list_insert (attrs, pango_attr_size_new (18));
+  pango_attr_list_insert (attrs, pango_attr_weight_new (PANGO_WEIGHT_ULTRABOLD));*/
+  label = gtk_label_new ("Autenticación");
+  /*g_object_set_data (G_OBJECT (label), "use_markup", GINT_TO_POINTER (FALSE));
+  g_object_set_data (G_OBJECT (label), "use_underline", GINT_TO_POINTER (FALSE));
+  gtk_label_set_attributes (GTK_LABEL (label), attrs);*/
+
   gtk_label_set_markup (GTK_LABEL (label),
 			"<span weight=\"ultrabold\" size=\"20000\">Autenticación</span>");
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 3);
   gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 3);
-  
+
+  image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_AUTHENTICATION, GTK_ICON_SIZE_DND);
+  gtk_box_pack_end (GTK_BOX (hbox), image, FALSE, FALSE, 3);
+  gtk_widget_show (image);  
+
+  hbox = gtk_hbox_new (FALSE, 3);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 3);
+  gtk_widget_show (hbox);
+
   label = gtk_label_new ("Nombre de Usuario: ");
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
   gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 3);
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 3);
 
   user_entry = gtk_entry_new_with_max_length (10);
   gtk_widget_show (user_entry);
-  gtk_box_pack_start (GTK_BOX (vbox), user_entry, FALSE, FALSE, 3);
+  gtk_box_pack_end (GTK_BOX (hbox), user_entry, FALSE, FALSE, 3);
 
   gtk_window_set_focus (GTK_WINDOW (passwd_window), user_entry);
 
+  hbox = gtk_hbox_new (FALSE, 3);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 3);
+  gtk_widget_show (hbox);
+
   label = gtk_label_new ("Contraseña: ");
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
   gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 3);
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 3);
 
   pass_entry = gtk_entry_new_with_max_length (15);
   gtk_entry_set_visibility (GTK_ENTRY (pass_entry), FALSE);
   gtk_widget_show (pass_entry);
-  gtk_box_pack_start (GTK_BOX (vbox), pass_entry, FALSE, FALSE, 3);
+  gtk_box_pack_end (GTK_BOX (hbox), pass_entry, FALSE, FALSE, 3);
 
   g_signal_connect (G_OBJECT (pass_entry), "activate",
 		    G_CALLBACK (CheckPasswd), NULL);
@@ -294,8 +317,9 @@ CheckPasswd (void)
       break;
     case FALSE:
       gtk_entry_set_text (GTK_ENTRY (user_entry), "");
-      gtk_entry_set_text (GTK_ENTRY (pass_entry), "");
-      AlertMSG (user_entry, "El Nombre de Usuario o Contraseña no son correctos");
+      gtk_entry_set_text (GTK_ENTRY (pass_entry), "");      
+      rizoma_error_window (user_entry);
+      //AlertMSG (user_entry, rizoma_error->motivo);
       break;
     default:
       break;
